==> nextcloud-15.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/serverinfo/l10n/bg.js <==
OC.L10N.register(
    "serverinfo",
    {
    "Load average" : "Средно натоварване",
    "Last minute" : "Последна минута",
    "Memory info not available" : "Информация за паметта не е налична",
    "Total" : "Общо",
    "Current usage" : "Текуща употреба",
    "Users" : "Потребители",
    "Groups" : "Групи",
    "Links" : "Връзки",
    "Last 24 hours" : "Последни 24 часа",
    "Last 1 hour" : "Последен 1 час",
    "Last 5 mins" : "Последни 5 минути",
    "Monitoring" : "Наблюдение",
    "CPU load" : "Натоварване на процесора",
    "Memory usage" : "Използвана памет",
    "Active users" : "Активни потребители",
    "Shares" : "Споделени папки",
    "Storage" : "Хранилище",
    "Users:" : "Потребители:",
    "Files:" : "Файлове:",
    "Free Space:" : "Свободно място:",
    "Version:" : "Версия:",
    "Apps installed:" : "Инсталирани приложения:",
    "Apps updates available:" : "Налични актуализации за приложения:",
    "PHP" : "PHP",
    "Memory Limit:" : "Лимит за памет:",
    "Max Execution Time:" : "Максимално време за изпълнение:",
    "Upload max size:" : "Максимално време за качване:",
    "Database" : "База данни",
    "Type:" : "Тип:",
    "Size:" : "Размер:",
    "External monitoring tool" : "Външно средство за мониторинг",
    "You can connect an external monitoring tool by using this end point:" : "Можете да свържете външен софтуер за мониторинг, чрез следния URL:",
    "You can connect an external monitoring tool by using this end point: " : "Можете да свържете външен софтуер за мониторинг, чрез следния URL:"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-15.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/serverinfo/l10n/bg.js <==
OC.L10N.register(
    "serverinfo",
    {
    "Load average" : "Средно натоварване",
    "Last minute" : "Последна минута",
    "Memory info not available" : "Информация за паметта не е налична",
    "Total" : "Общо",
    "Current usage" : "Текуща употреба",
    "Users" : "Потребители",
    "Groups" : "Групи",
    "Links" : "Връзки",
    "Last 24 hours" : "Последни 24 часа",
    "Last 1 hour" : "Последен 1 час",
    "Last 5 mins" : "Последни 5 минути",
    "Press ⌘-C to copy." : "За копиране натиснете ⌘-C.",
    "Press Ctrl-C to copy." : "За копиране натиснете Ctrl-C.",
    "Monitoring" : "Наблюдение",
    "CPU load" : "Натоварване на процесора",
    "Memory usage" : "Използвана памет",
    "Active users" : "Активни потребители",
    "Shares" : "Споделени папки",
    "Storage" : "Хранилище",
    "Users:" : "Потребители:",
    "Files:" : "Файлове:",
    "Free Space:" : "Свободно място:",
    "Nextcloud" : "Nextcloud",
    "Version:" : "Версия:",
    "Apps installed:" : "Инсталирани приложения:",
    "Apps updates available:" : "Налични актуализации за приложения:",
    "PHP" : "PHP",
    "Memory Limit:" : "Лимит за памет:",
    "Max Execution Time:" : "Максимално време за изпълнение:",
    "Upload max size:" : "Максимално време за качване:",
    "Database" : "База данни",
    "Type:" : "Тип:",
    "Size:" : "Размер:",
    "External monitoring tool" : "Външно средство за мониторинг",
    "You can connect an external monitoring tool by using this end point:" : "Можете да свържете външен софтуер за мониторинг, чрез следния URL:",
    "Did you know?" : "Известно ли ви е?",
    "You can connect an external monitoring tool by using this end point: " : "Можете да свържете външен софтуер за мониторинг, чрез следния URL:"
},
"nplurals=2; plural=(n != 1);");
